@@ -52,7 +52,7 @@ sub test_expand_pragma {
 sub per_test {
   my($class, $testspec) = @_;
   return unless $testspec->app->test_expand;
-  return qq(# per-test comment\n);
+  return 0, qq(# per-test comment\n);
 }
 
 1; # Magic true value required at end of module
